sequencetools.is_strictly_decreasing_sequence
=============================================

.. autofunction:: abjad.tools.sequencetools.is_strictly_decreasing_sequence.is_strictly_decreasing_sequence
